netapp_ontap.models.nvme_subsystem_host_io_queue API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_subsystem_host_io_queue`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeSubsystemHostIoQueueSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemHostIoQueue object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `count GET`

    The number of I/O queue pairs. The default value is inherited from the owning NVMe subsystem.

    Example: 4

  `depth GET`

    The I/O queue depth. The default value is inherited from the owning NVMe subsystem.

    Example: 32